@@ -12,7 +12,7 @@
 const express = require('express'),
       router = express.Router(),
       app = require('./app'),
-      inspect = require('security-middleware')
+      inspect = require('@stolostron/security-middleware')
 
 router.all(['/', '/*'], inspect.ui(), app)
 
