@@ -212,7 +212,7 @@ function (_Component) {
     _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleClickOutside", function (evt) {
       var shouldPreventClose = evt && evt.target && _this._tooltipEl && _this._tooltipEl.contains(evt.target);
 
-      if (!shouldPreventClose) {
+      if (!shouldPreventClose && _this.state.open) {
         _this.setState({
           open: false
         });
