@@ -26,6 +26,9 @@ var items = [{
 }, {
   label: 'Option 5',
   value: 'router'
+}, {
+  label: 'An example option that is really long to show what should be done to handle long text',
+  value: 'loremipsum'
 }];
 module.exports = {
   context: {
