@@ -1,9 +1,3 @@
-/**
- * Copyright IBM Corp. 2016, 2018
- *
- * This source code is licensed under the Apache-2.0 license found in the
- * LICENSE file in the root directory of this source tree.
- */
 export var keys = {
   TAB: 9,
   ENTER: 13,
@@ -18,6 +12,7 @@ export var keys = {
   RIGHT: 39,
   DOWN: 40
 };
+
 /**
  * Check to see if at least one key code matches the key code of the
  * given event.
@@ -33,16 +28,15 @@ export var keys = {
  * @param {Array<number>} keysToMatch
  * @returns {boolean}
  */
-
 export function matches(event, keysToMatch) {
   for (var i = 0; i < keysToMatch.length; i++) {
     if (keysToMatch[i] === event.which) {
       return true;
     }
   }
-
   return false;
 }
+
 /**
  * Check to see if the given key matches the corresponding keyboard event. Also
  * supports passing in the value directly if you can't used the given event.
@@ -58,10 +52,10 @@ export function matches(event, keysToMatch) {
  * @param {number} key - the `which` value, should come from keys
  * @returns {boolean}
  */
-
 export function match(eventOrCode, key) {
-  return eventOrCode && eventOrCode.which === key || eventOrCode === key;
+  return eventOrCode.which === key || eventOrCode === key;
 }
+
 /**
  * Get a string character for a given event or event code (useful for synthetic
  * events)
@@ -69,7 +63,6 @@ export function match(eventOrCode, key) {
  * @param {Event|number} eventOrCode
  * @returns {string}
  */
-
 export function getCharacterFor(eventOrCode) {
   if (typeof eventOrCode === 'number') {
     return String.fromCharCode(eventOrCode);
