@@ -7,10 +7,10 @@ import { css } from '@patternfly/react-styles';
 import TimesCircleIcon from '@patternfly/react-icons/dist/js/icons/times-circle-icon';
 import { SelectMenu } from './SelectMenu';
 import { SelectOption, SelectOptionObject } from './SelectOption';
-import { SelectGroup } from './SelectGroup';
+import { SelectGroup, SelectGroupProps } from './SelectGroup';
 import { SelectToggle } from './SelectToggle';
 import { SelectContext, SelectVariant, SelectDirection, KeyTypes } from './selectConstants';
-import { Chip, ChipGroup } from '../ChipGroup';
+import { Chip, ChipGroup, ChipGroupProps } from '../ChipGroup';
 import {
   keyHandler,
   getNextIndex,
@@ -31,7 +31,7 @@ export interface SelectProps
   extends ToggleMenuBaseProps,
     Omit<React.HTMLProps<HTMLDivElement>, 'onSelect' | 'ref' | 'checked' | 'selected'>,
     OUIAProps {
-  /** Content rendered inside the Select */
+  /** Content rendered inside the Select. Must be React.ReactElement<SelectGroupProps>[] */
   children?: React.ReactElement[];
   /** Classes applied to the root of the Select */
   className?: string;
@@ -109,6 +109,10 @@ export interface SelectProps
   customBadgeText?: string | number;
   /** Prefix for the id of the input in the checkbox select variant*/
   inputIdPrefix?: string;
+  /** Optional props to pass to the chip group in the typeaheadmulti variant */
+  chipGroupProps?: Omit<ChipGroupProps, 'children' | 'ref'>;
+  /** Optional props to render custom chip group in the typeaheadmulti variant */
+  chipGroupComponent?: React.ReactNode;
 }
 
 export interface SelectState {
@@ -167,7 +171,8 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
     menuAppendTo: 'inline',
     favorites: [] as string[],
     favoritesLabel: 'Favorites',
-    ouiaSafe: true
+    ouiaSafe: true,
+    chipGroupComponent: null
   };
 
   state: SelectState = {
@@ -200,15 +205,10 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       });
     }
 
-    if (prevProps.selections !== this.props.selections && this.props.variant === SelectVariant.typeahead) {
-      this.setState({
-        typeaheadInputValue: this.props.selections as string
-      });
-    }
-
     if (
-      this.props.favorites.length !== prevProps.favorites.length ||
-      this.state.typeaheadFilteredChildren !== prevState.typeaheadFilteredChildren
+      this.props.onFavorite &&
+      (this.props.favorites.length !== prevProps.favorites.length ||
+        this.state.typeaheadFilteredChildren !== prevState.typeaheadFilteredChildren)
     ) {
       const tempRenderableChildren =
         this.props.variant === 'typeahead' || this.props.variant === 'typeaheadmulti'
@@ -223,7 +223,8 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
         ? [
             <SelectGroup key="favorites" label={this.props.favoritesLabel}>
               {renderableFavorites}
-            </SelectGroup>
+            </SelectGroup>,
+            <Divider key="favorites-group-divider" />
           ]
         : [];
       this.setState({ favoritesGroup });
@@ -261,27 +262,25 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       } catch (err) {
         input = new RegExp(e.target.value.toString().replace(/[.*+?^${}()|[\]\\]/g, '\\$&'), 'i');
       }
-      const childrenArray = React.Children.toArray(children);
+      const childrenArray = React.Children.toArray(children) as React.ReactElement<SelectGroupProps>[];
       if (isGrouped) {
+        const childFilter = (child: React.ReactElement<SelectGroupProps>) =>
+          child.props.value && this.getDisplay(child.props.value.toString(), 'text').search(input) === 0;
         typeaheadFilteredChildren =
           e.target.value.toString() !== ''
-            ? React.Children.map(children, (group: React.ReactElement) => {
+            ? React.Children.map(children, group => {
                 if (group.type === SelectGroup) {
-                  const filteredGroupChildren = React.Children.toArray(group.props.children).filter(
-                    (child: React.ReactElement) =>
-                      this.getDisplay(child.props.value.toString(), 'text').search(input) === 0
-                  );
+                  const filteredGroupChildren = (React.Children.toArray(group.props.children) as React.ReactElement<
+                    SelectGroupProps
+                  >[]).filter(childFilter);
                   if (filteredGroupChildren.length > 0) {
                     return React.cloneElement(group, {
                       titleId: group.props.label && group.props.label.replace(/\W/g, '-'),
-                      children: filteredGroupChildren
+                      children: filteredGroupChildren as any
                     });
                   }
                 } else {
-                  return React.Children.toArray(group).filter(
-                    (child: React.ReactElement) =>
-                      this.getDisplay(child.props.value.toString(), 'text').search(input) === 0
-                  );
+                  return (React.Children.toArray(group) as React.ReactElement<SelectGroupProps>[]).filter(childFilter);
                 }
               })
             : childrenArray;
@@ -336,7 +335,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
   };
 
   extendTypeaheadChildren(typeaheadCurrIndex: number, favoritesGroup?: React.ReactNode[]) {
-    const { isGrouped } = this.props;
+    const { isGrouped, onFavorite } = this.props;
     const typeaheadChildren = favoritesGroup
       ? favoritesGroup.concat(this.state.typeaheadFilteredChildren)
       : this.state.typeaheadFilteredChildren;
@@ -347,42 +346,68 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       typeaheadActiveChild = typeaheadActiveChild.firstElementChild as HTMLElement;
     }
 
+    this.refCollection = [[]];
+    this.optionContainerRefCollection = [];
     if (isGrouped) {
       return React.Children.map(typeaheadChildren as React.ReactElement[], (group: React.ReactElement) => {
-        if (group.type === SelectGroup) {
+        if (group.type === Divider) {
+          return group;
+        } else if (group.type === SelectGroup && onFavorite) {
           return React.cloneElement(group, {
             titleId: group.props.label && group.props.label.replace(/\W/g, '-'),
             children: React.Children.map(group.props.children, (child: React.ReactElement) =>
-              React.cloneElement(child as React.ReactElement, {
-                isFocused:
-                  activeElement &&
-                  (activeElement.id === (child as React.ReactElement).props.id ||
-                    (this.props.isCreatable &&
-                      typeaheadActiveChild.innerText === `{createText} "${(child as React.ReactElement).props.value}"`))
-              })
+              child.type === Divider
+                ? child
+                : React.cloneElement(child as React.ReactElement, {
+                    isFocused:
+                      activeElement &&
+                      (activeElement.id === (child as React.ReactElement).props.id ||
+                        (this.props.isCreatable &&
+                          typeaheadActiveChild.innerText ===
+                            `{createText} "${(group as React.ReactElement).props.value}"`))
+                  })
+            )
+          });
+        } else if (group.type === SelectGroup) {
+          return React.cloneElement(group, {
+            titleId: group.props.label && group.props.label.replace(/\W/g, '-'),
+            children: React.Children.map(group.props.children, (child: React.ReactElement) =>
+              child.type === Divider
+                ? child
+                : React.cloneElement(child as React.ReactElement, {
+                    isFocused:
+                      typeaheadActiveChild &&
+                      (typeaheadActiveChild.innerText === (child as React.ReactElement).props.value.toString() ||
+                        (this.props.isCreatable &&
+                          typeaheadActiveChild.innerText ===
+                            `{createText} "${(child as React.ReactElement).props.value}"`))
+                  })
             )
           });
         } else {
-          return React.cloneElement(group, {
+          // group has been filtered down to SelectOption
+          return React.cloneElement(group as React.ReactElement, {
             isFocused:
               typeaheadActiveChild &&
-              (typeaheadActiveChild.id === (group as React.ReactElement).props.id ||
-                (this.props.isCreatable &&
-                  typeaheadActiveChild.innerText === `{createText} "${(group as React.ReactElement).props.value}"`))
+              (typeaheadActiveChild.innerText === group.props.value.toString() ||
+                (this.props.isCreatable && typeaheadActiveChild.innerText === `{createText} "${group.props.value}"`))
           });
         }
       });
     }
 
-    return typeaheadChildren.map((child: React.ReactNode) =>
-      React.cloneElement(child as React.ReactElement, {
-        isFocused:
-          typeaheadActiveChild &&
-          (typeaheadActiveChild.innerText === (child as React.ReactElement).props.value.toString() ||
-            (this.props.isCreatable &&
-              typeaheadActiveChild.innerText === `{createText} "${(child as React.ReactElement).props.value}"`))
-      })
-    );
+    return typeaheadChildren.map((child: React.ReactNode) => {
+      const childElement = child as any;
+      return childElement.type.displayName === 'Divider'
+        ? child
+        : React.cloneElement(child as React.ReactElement, {
+            isFocused:
+              typeaheadActiveChild &&
+              (typeaheadActiveChild.innerText === (child as React.ReactElement).props.value.toString() ||
+                (this.props.isCreatable &&
+                  typeaheadActiveChild.innerText === `{createText} "${(child as React.ReactElement).props.value}"`))
+          });
+    });
   }
 
   sendRef = (
@@ -484,23 +509,31 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
         this.moveFocus(nextIndex);
       } else {
         const nextIndex = this.refCollection.findIndex(
-          ref => ref[0] === document.activeElement || ref[1] === document.activeElement
+          ref => ref !== undefined && (ref[0] === document.activeElement || ref[1] === document.activeElement)
         );
         this.moveFocus(nextIndex);
       }
     }
   };
 
+  onClickTypeaheadToggleButton = () => {
+    if (this.inputRef && this.inputRef.current) {
+      this.inputRef.current.focus();
+    }
+  };
+
   getDisplay = (value: string | SelectOptionObject, type: 'node' | 'text' = 'node') => {
     if (!value) {
       return;
     }
     const item = this.props.isGrouped
-      ? React.Children.toArray<React.ReactElement>(this.props.children)
+      ? (React.Children.toArray(this.props.children) as React.ReactElement[])
           .reduce((acc, curr) => [...acc, ...React.Children.toArray(curr.props.children)], [])
           .find(child => child.props.value.toString() === value.toString())
-      : React.Children.toArray<React.ReactElement>(this.props.children).find(
-          child => child.props.value.toString() === value.toString()
+      : React.Children.toArray(this.props.children).find(
+          child =>
+            (child as React.ReactElement).props.value &&
+            (child as React.ReactElement).props.value.toString() === value.toString()
         );
     if (item) {
       if (item && item.props.children) {
@@ -511,24 +544,19 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
       }
       return item.props.value.toString();
     }
-    return value;
+    return value.toString();
   };
 
-  findText: (item: React.ReactElement) => string = (item: React.ReactElement) => {
-    if (!item.props || !item.props.children) {
-      if (typeof item !== 'string') {
-        return '';
-      }
+  findText = (item: React.ReactNode) => {
+    if (typeof item === 'string') {
       return item;
+    } else if (!React.isValidElement(item)) {
+      return '';
+    } else {
+      const multi: string[] = [];
+      React.Children.toArray(item.props.children).forEach(child => multi.push(this.findText(child)));
+      return multi.join('');
     }
-    if (typeof item.props.children === 'string') {
-      return item.props.children;
-    }
-    const multi: string[] = [];
-    React.Children.toArray(item.props.children).forEach((child: React.ReactElement) =>
-      multi.push(this.findText(child))
-    );
-    return multi.join('');
   };
 
   generateSelectedBadge = () => {
@@ -545,6 +573,8 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
   render() {
     const {
       children,
+      chipGroupProps,
+      chipGroupComponent,
       className,
       customContent,
       variant,
@@ -653,8 +683,10 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
 
     let selectedChips = null as any;
     if (variant === SelectVariant.typeaheadMulti) {
-      selectedChips = (
-        <ChipGroup>
+      selectedChips = chipGroupComponent ? (
+        chipGroupComponent
+      ) : (
+        <ChipGroup {...chipGroupProps}>
           {selections &&
             (selections as string[]).map(item => (
               <Chip
@@ -736,6 +768,9 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
             openedOnEnter
           };
           variantChildren = onFavorite ? renderableItems : this.extendTypeaheadChildren(typeaheadCurrIndex);
+          if (variantChildren.length === 0) {
+            variantChildren.push(<SelectOption isDisabled key={0} value={noResultsFoundText} isNoResultsOption />);
+          }
           break;
         case 'typeaheadmulti':
           variantProps = {
@@ -743,6 +778,9 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
             openedOnEnter
           };
           variantChildren = onFavorite ? renderableItems : this.extendTypeaheadChildren(typeaheadCurrIndex);
+          if (variantChildren.length === 0) {
+            variantChildren.push(<SelectOption isDisabled key={0} value={noResultsFoundText} isNoResultsOption />);
+          }
           break;
       }
     }
@@ -806,6 +844,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
           handleTypeaheadKeys={this.handleTypeaheadKeys}
           isDisabled={isDisabled}
           hasClearButton={hasOnClear}
+          onClickTypeaheadToggleButton={this.onClickTypeaheadToggleButton}
         >
           {customContent && (
             <div className={css(styles.selectToggleWrapper)}>
@@ -863,7 +902,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
                   ref={this.inputRef}
                 />
               </div>
-              {(selections[0] || typeaheadInputValue) && clearBtn}
+              {hasOnClear && (selections[0] || typeaheadInputValue) && clearBtn}
             </React.Fragment>
           )}
           {variant === SelectVariant.typeaheadMulti && !customContent && (
@@ -886,7 +925,7 @@ export class Select extends React.Component<SelectProps & OUIAProps, SelectState
                   ref={this.inputRef}
                 />
               </div>
-              {((selections && selections.length > 0) || typeaheadInputValue) && clearBtn}
+              {hasOnClear && ((selections && selections.length > 0) || typeaheadInputValue) && clearBtn}
             </React.Fragment>
           )}
         </SelectToggle>
